@@ -186,7 +186,6 @@ macro_rules! preset_root {
 			$crate::crate_authors!(),
 			$crate::crate_version!(),
 			$crate::crate_description!(),
-			$crate::command::License::SPDXExpr($crate::crate_license!().into()),
 			None
 			),
 	};
@@ -196,7 +195,6 @@ macro_rules! preset_root {
 			$crate::crate_authors!(),
 			$crate::crate_version!(),
 			$crate::crate_description!(),
-			$crate::command::License::SPDXExpr($crate::crate_license!().into()),
 			Some($action))
 	}
 }
@@ -227,12 +225,12 @@ macro_rules! cmd {
 			license=>$license:expr,
 			description=>$desc:expr,
 			usage=>$usage:expr,
-			local_flags:$l_flags:expr,
-			commcon_flags:$c_flags:expr,
-			alias: $alias:expr,
-			version: $ver:expr,
-			sub: $sub:expr,
-			help: $help:expr
+			local_flags=>$l_flags:expr,
+			commcon_flags=>$c_flags:expr,
+			alias=> $alias:expr,
+			version=> $ver:expr,
+			sub=> $sub:expr,
+			help=> $help:expr
 		]
 	) => {
 		Command::with_all_field(
@@ -252,3 +250,49 @@ macro_rules! cmd {
 		)
 	};
 }
+
+#[macro_export]
+/// Creates function returns given string
+macro_rules! string_fn {
+	($string:expr) => {
+		|_ctx: &Context| -> String { $string }
+	};
+	(into=>$str:expr) => {
+		string_fn!($str.into())
+	};
+	(file_path=>$file_path:expr) => {
+		string_fn!(include_str!($file_path))
+	};
+}
+
+#[macro_export]
+/// create license helper
+macro_rules! license {
+	(none) => {
+		$crate::command::License(None)
+	};
+	(expr=>$expr:expr, outputter=>$fn:expr) => {
+		$crate::command::License(Some(($expr, $fn)))
+	};
+	($expr:expr,outputter=>$fn:expr)=>{
+		license!(expr=>$expr,outputter=>$fn)
+	};
+	($expr:expr,$fn:expr)=>{
+		license!(expr=>$expr,outputter=>$fn)
+	};
+	($expr:expr, content=>$content:expr) => {
+		license!($expr, $crate::string_fn!($content))
+	};
+	($expr:expr, file_path=>$file_path:expr) => {
+		license!($expr, $crate::string_fn!(file_path=>$file_path))
+	};
+	($expr:expr, $c:expr$(,)?)=>{
+		license!($expr,$c)
+	};
+	($expr:expr, $i:ident=>$c:expr$(,)?)=>{
+		license!($expr,$i=>$c)
+	};
+	($e:ident=>$expr:expr, $i:ident=>$c:expr$(,)?)=>{
+		license!($expr,$i=>$c)
+	}
+}
